@@ -6,10 +6,15 @@
 
 #include <glib-object.h>
 
+#ifdef HAVE_X11
+#include <X11/Xlib.h>
+#endif
+
 #include <clutter/clutter.h>
 #include <meta/common.h>
 #include <meta/display.h>
 #include <meta/keybindings.h>
+#include <meta/meta-backend.h>
 #include <meta/meta-context.h>
 #include <meta/util.h>
 #include <meta/meta-window-config.h>
@@ -24,12 +29,16 @@
 #include "kiosk-service.h"
 #include "kiosk-app-system.h"
 #include "kiosk-window-tracker.h"
+#include "kiosk-shell-service.h"
 #include "kiosk-shell-introspect-service.h"
 #include "kiosk-shell-screenshot-service.h"
 #include "kiosk-window-config.h"
 
 #include "org.gnome.DisplayManager.Manager.h"
 
+#define GNOME_DESKTOP_INTERFACE_SCHEMA "org.gnome.desktop.interface"
+#define GNOME_DESKTOP_ENABLE_ANIMATIONS "enable-animations"
+
 struct _KioskCompositor
 {
         MetaPlugin                   parent;
@@ -51,6 +60,8 @@ struct _KioskCompositor
         KioskShellIntrospectService *introspect_service;
         KioskShellScreenshotService *screenshot_service;
         KioskWindowConfig           *kiosk_window_config;
+        KioskShellService           *shell_service;
+        GSettings                   *interface_settings;
 };
 
 enum
@@ -64,8 +75,6 @@ static guint signals[NUMBER_OF_SIGNALS] = { 0, };
 G_DEFINE_TYPE (KioskCompositor, kiosk_compositor, META_TYPE_PLUGIN)
 
 static void kiosk_compositor_dispose (GObject *object);
-static gboolean kiosk_compositor_wants_window_fullscreen (KioskCompositor *self,
-                                                          MetaWindow      *window);
 
 static void
 kiosk_compositor_dispose (GObject *object)
@@ -77,13 +86,22 @@ kiosk_compositor_dispose (GObject *object)
                 g_clear_object (&self->cancellable);
         }
 
-        g_clear_weak_pointer (&self->stage);
-        g_clear_weak_pointer (&self->context);
-        g_clear_weak_pointer (&self->display);
-        g_clear_weak_pointer (&self->backend);
-
         g_clear_object (&self->backgrounds);
         g_clear_object (&self->automount_manager);
+        g_clear_object (&self->input_sources_manager);
+        g_clear_object (&self->app_system);
+        g_clear_object (&self->tracker);
+        g_clear_object (&self->kiosk_window_config);
+        g_clear_object (&self->introspect_service);
+        g_clear_object (&self->screenshot_service);
+        g_clear_object (&self->shell_service);
+        g_clear_object (&self->interface_settings);
+        g_clear_object (&self->service);
+
+        g_clear_weak_pointer (&self->display);
+        g_clear_weak_pointer (&self->context);
+        g_clear_weak_pointer (&self->backend);
+        g_clear_weak_pointer (&self->stage);
 
         G_OBJECT_CLASS (kiosk_compositor_parent_class)->dispose (object);
 }
@@ -225,39 +243,6 @@ neuter_builtin_keybindings (KioskCompositor *self)
         }
 }
 
-static void
-kiosk_compositor_on_window_configure (MetaWindow       *window,
-                                      MetaWindowConfig *window_config,
-                                      gpointer          user_data)
-{
-        KioskCompositor *self = KIOSK_COMPOSITOR (user_data);
-        gboolean fullscreen;
-
-        if (!meta_window_config_get_is_initial (window_config)) {
-                g_debug ("KioskCompositor: Ignoring configure for window: %s",
-                         meta_window_get_description (window));
-                return;
-        }
-
-        g_debug ("KioskCompositor: configure window: %s", meta_window_get_description (window));
-
-        fullscreen = kiosk_compositor_wants_window_fullscreen (self, window);
-        meta_window_config_set_is_fullscreen (window_config, fullscreen);
-        kiosk_window_config_update_window (self->kiosk_window_config,
-                                           window,
-                                           window_config);
-}
-
-static void
-kiosk_compositor_on_window_created (MetaDisplay *display,
-                                    MetaWindow  *window,
-                                    gpointer     user_data)
-{
-        g_signal_connect (window, "configure",
-                          G_CALLBACK (kiosk_compositor_on_window_configure),
-                          user_data);
-}
-
 static void
 kiosk_compositor_start (MetaPlugin *plugin)
 {
@@ -290,27 +275,26 @@ kiosk_compositor_start (MetaPlugin *plugin)
         self->input_sources_manager = kiosk_input_sources_manager_new (self);
         self->app_system = kiosk_app_system_new (self);
         self->tracker = kiosk_window_tracker_new (self, self->app_system);
-        self->kiosk_window_config = kiosk_window_config_new ();
+        self->kiosk_window_config = kiosk_window_config_new (self);
         self->introspect_service = kiosk_shell_introspect_service_new (self);
         kiosk_shell_introspect_service_start (self->introspect_service, &error);
         self->screenshot_service = kiosk_shell_screenshot_service_new (self);
         kiosk_shell_screenshot_service_start (self->screenshot_service, &error);
+        self->shell_service = kiosk_shell_service_new (self);
+        kiosk_shell_service_start (self->shell_service, &error);
 
         if (error != NULL) {
                 g_debug ("KioskCompositor: Could not start D-Bus service: %s", error->message);
                 g_clear_error (&error);
         }
 
+        self->interface_settings = g_settings_new (GNOME_DESKTOP_INTERFACE_SCHEMA);
+
         kiosk_gobject_utils_queue_immediate_callback (G_OBJECT (self),
                                                       "[kiosk-compositor] register_session",
                                                       self->cancellable,
                                                       KIOSK_OBJECT_CALLBACK (register_session),
                                                       NULL);
-
-        g_signal_connect_object (self->display, "window-created",
-                                 G_CALLBACK (kiosk_compositor_on_window_created),
-                                 self,
-                                 G_CONNECT_DEFAULT);
 }
 
 static void
@@ -344,69 +328,6 @@ kiosk_compositor_size_change (MetaPlugin      *plugin,
         g_assert (META_PLUGIN_CLASS (kiosk_compositor_parent_class)->size_change == NULL);
 }
 
-static gboolean
-kiosk_compositor_wants_window_fullscreen (KioskCompositor *self,
-                                          MetaWindow      *window)
-{
-        MetaWindowType window_type;
-
-        g_autoptr (GList) windows = NULL;
-        GList *node;
-
-        if (!meta_window_allows_resize (window)) {
-                g_debug ("KioskCompositor: Window does not allow resizes");
-                return FALSE;
-        }
-
-        if (meta_window_is_override_redirect (window)) {
-                g_debug ("KioskCompositor: Window is override redirect");
-                return FALSE;
-        }
-
-        window_type = meta_window_get_window_type (window);
-
-        if (window_type != META_WINDOW_NORMAL) {
-                g_debug ("KioskCompositor: Window is not normal");
-                return FALSE;
-        }
-
-        windows = meta_display_get_tab_list (self->display, META_TAB_LIST_NORMAL_ALL, NULL);
-
-        for (node = windows; node != NULL; node = node->next) {
-                MetaWindow *existing_window = node->data;
-
-                if (meta_window_is_monitor_sized (existing_window)) {
-                        return FALSE;
-                }
-        }
-
-        return TRUE;
-}
-
-static gboolean
-kiosk_compositor_wants_window_above (KioskCompositor *self,
-                                     MetaWindow      *window)
-{
-        gboolean set_above;
-
-        if (kiosk_window_config_get_boolean_for_window (self->kiosk_window_config,
-                                                        window,
-                                                        "set-above",
-                                                        &set_above))
-                return set_above;
-
-        /* If not specified in the config, use the heuristics */
-        if (meta_window_is_screen_sized (window)) {
-                return FALSE;
-        }
-
-        if (meta_window_is_monitor_sized (window)) {
-                return FALSE;
-        }
-
-        return TRUE;
-}
-
 static void
 on_faded_in (KioskCompositor   *self,
              ClutterTransition *transition)
@@ -417,31 +338,30 @@ on_faded_in (KioskCompositor   *self,
 }
 
 static void
-kiosk_compositor_map (MetaPlugin      *plugin,
-                      MetaWindowActor *actor)
+kiosk_compositor_map_immediately (KioskCompositor *self,
+                                  MetaWindowActor *actor)
+{
+        g_debug ("KioskCompositor: Animations disabled, mapping window immediately");
+        clutter_actor_set_opacity (CLUTTER_ACTOR (actor), 255);
+        meta_plugin_map_completed (META_PLUGIN (self), actor);
+}
+
+static void
+kiosk_compositor_map_with_fade_in (KioskCompositor *self,
+                                   MetaWindowActor *actor,
+                                   MetaWindow      *window)
 {
-        KioskCompositor *self = KIOSK_COMPOSITOR (plugin);
-        MetaWindow *window;
         ClutterTransition *fade_in_transition;
         int easing_duration;
 
-        window = meta_window_actor_get_meta_window (actor);
-
         if (meta_window_is_fullscreen (window)) {
                 g_debug ("KioskCompositor: Mapping window that does need to be fullscreened");
                 easing_duration = 3000;
         } else {
                 g_debug ("KioskCompositor: Mapping window that does not need to be fullscreened");
-
-                if (kiosk_compositor_wants_window_above (self, window))
-                        meta_window_make_above (window);
-
                 easing_duration = 500;
         }
 
-        clutter_actor_show (self->stage);
-        clutter_actor_show (CLUTTER_ACTOR (actor));
-
         clutter_actor_set_opacity (CLUTTER_ACTOR (actor), 0);
 
         clutter_actor_save_easing_state (CLUTTER_ACTOR (actor));
@@ -460,6 +380,31 @@ kiosk_compositor_map (MetaPlugin      *plugin,
                                  G_CONNECT_SWAPPED);
 }
 
+static void
+kiosk_compositor_map (MetaPlugin      *plugin,
+                      MetaWindowActor *actor)
+{
+        KioskCompositor *self = KIOSK_COMPOSITOR (plugin);
+        MetaWindow *window;
+        gboolean animations_enabled;
+
+        window = meta_window_actor_get_meta_window (actor);
+
+        kiosk_window_config_apply_initial_config (self->kiosk_window_config, window);
+
+        clutter_actor_show (self->stage);
+        clutter_actor_show (CLUTTER_ACTOR (actor));
+
+        animations_enabled = g_settings_get_boolean (self->interface_settings,
+                                                     GNOME_DESKTOP_ENABLE_ANIMATIONS);
+
+        if (animations_enabled) {
+                kiosk_compositor_map_with_fade_in (self, actor, window);
+        } else {
+                kiosk_compositor_map_immediately (self, actor);
+        }
+}
+
 static void
 kiosk_compositor_destroy (MetaPlugin      *plugin,
                           MetaWindowActor *actor)
@@ -527,6 +472,7 @@ kiosk_compositor_show_window_menu_for_rect (MetaPlugin         *plugin,
         g_assert (META_PLUGIN_CLASS (kiosk_compositor_parent_class)->show_window_menu_for_rect == NULL);
 }
 
+#ifdef HAVE_X11
 static gboolean
 kiosk_compositor_xevent_filter (MetaPlugin *plugin,
                                 XEvent     *x_server_event)
@@ -536,6 +482,7 @@ kiosk_compositor_xevent_filter (MetaPlugin *plugin,
         g_signal_emit (G_OBJECT (self), signals[X_SERVER_EVENT], 0, x_server_event);
         return FALSE;
 }
+#endif /* HAVE_X11 */
 
 static gboolean
 kiosk_compositor_keybinding_filter (MetaPlugin     *plugin,
@@ -559,13 +506,6 @@ kiosk_compositor_create_close_dialog (MetaPlugin *plugin,
         return NULL;
 }
 
-static MetaInhibitShortcutsDialog *
-kiosk_compositor_create_inhibit_shortcuts_dialog (MetaPlugin *plugin,
-                                                  MetaWindow *window)
-{
-        return NULL;
-}
-
 static void
 kiosk_compositor_locate_pointer (MetaPlugin *plugin)
 {
@@ -597,13 +537,14 @@ kiosk_compositor_class_init (KioskCompositorClass *compositor_class)
         plugin_class->show_window_menu = kiosk_compositor_show_window_menu;
         plugin_class->show_window_menu_for_rect = kiosk_compositor_show_window_menu_for_rect;
 
+#ifdef HAVE_X11
         plugin_class->xevent_filter = kiosk_compositor_xevent_filter;
+#endif /* HAVE_X11 */
         plugin_class->keybinding_filter = kiosk_compositor_keybinding_filter;
 
         plugin_class->confirm_display_change = kiosk_compositor_confirm_display_change;
 
         plugin_class->create_close_dialog = kiosk_compositor_create_close_dialog;
-        plugin_class->create_inhibit_shortcuts_dialog = kiosk_compositor_create_inhibit_shortcuts_dialog;
 
         plugin_class->locate_pointer = kiosk_compositor_locate_pointer;
 
