@@ -6,6 +6,8 @@
 #include "kiosk-backgrounds.h"
 #include "kiosk-input-sources-manager.h"
 #include "kiosk-service.h"
+#include "kiosk-app-system.h"
+#include "kiosk-window-tracker.h"
 
 G_BEGIN_DECLS
 #define KIOSK_TYPE_COMPOSITOR (kiosk_compositor_get_type ())
@@ -17,4 +19,7 @@ G_DECLARE_FINAL_TYPE (KioskCompositor, kiosk_compositor,
 KioskBackgrounds *kiosk_compositor_get_backgrounds (KioskCompositor *compositor);
 KioskInputSourcesManager *kiosk_compositor_get_input_sources_manager (KioskCompositor *compositor);
 KioskService *kiosk_compositor_get_service (KioskCompositor *compositor);
+KioskAppSystem *kiosk_compositor_get_app_system (KioskCompositor *compositor);
+KioskWindowTracker *kiosk_compositor_get_window_tracker (KioskCompositor *compositor);
+
 G_END_DECLS
